//  SuperTux
//  Copyright (C) 2015 Hume2 <teratux.mail@gmail.com>
//
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef HEADER_SUPERTUX_EDITOR_UTIL_HPP
#define HEADER_SUPERTUX_EDITOR_UTIL_HPP

#include <stdint.h>

#include "video/color.hpp"
#include "math/fwd.hpp"

class Canvas;
class TileSet;

void
draw_tile(Canvas& canvas, const TileSet& tileset, uint32_t id, const Vector& pos,
          int z_pos, const Color& color = Color(1, 1, 1));

#endif

/* EOF */
